@@ -66,11 +66,11 @@ class NativeHWManagementService(Service):
     def hw_management_service_set_logging_endpoint(self, param_dict, **kwargs):
         return self._grpc_helper(self.stub.SetLoggingEndpoint, hw_management_service_pb2.SetLoggingEndpointRequest, param_dict, **kwargs)
 
-    # rpc GetLoggingEndpoint(Uuid) returns(GetLoggingEndpointResponse);
+    # rpc GetLoggingEndpoint(HardwareID) returns(GetLoggingEndpointResponse);
     @keyword
     @is_connected
     def hw_management_service_get_logging_endpoint(self, param_dict, **kwargs):
-        return self._grpc_helper(self.stub.GetLoggingEndpoint, hw_pb2.Uuid, param_dict)
+        return self._grpc_helper(self.stub.GetLoggingEndpoint, hw_pb2.HardwareID, param_dict)
 
     # rpc SetMsgBusEndpoint(SetMsgBusEndpointRequest) returns(SetRemoteEndpointResponse);
     @keyword
@@ -101,3 +101,15 @@ class NativeHWManagementService(Service):
     @is_connected
     def hw_management_service_get_log_level(self, param_dict, **kwargs):
         return self._grpc_helper(self.stub.GetLogLevel, hw_management_service_pb2.GetLogLevelRequest, param_dict, **kwargs)
+
+    # rpc HeartbeatCheck(google.protobuf.Empty) returns (Heartbeat);
+    @keyword
+    @is_connected
+    def hw_management_service_heartbeat_check(self, **kwargs):
+        return self._grpc_helper(self.stub.HeartbeatCheck, **kwargs)
+
+    # rpc RebootDevice(RebootDeviceRequest) returns(RebootDeviceResponse);
+    @keyword
+    @is_connected
+    def hw_management_service_reboot_device(self, param_dict, **kwargs):
+        return self._grpc_helper(self.stub.RebootDevice, hw_management_service_pb2.RebootDeviceRequest, param_dict, **kwargs)
