@@ -43,7 +43,7 @@ class VolthaTools(object):
         | Import Library | grpc_robot.VolthaTools | WITH NAME | voltha_tools |
         | ${kafka_records} | kafka.Records Get |
         | FOR | ${kafka_record} | IN | @{kafka_records} |
-        |  | ${event} | voltha_tools.Event Decode Event | ${kafka_record}[message] |
+        |  | ${event} | voltha_tools.Events Decode Event | ${kafka_record}[message] |
         |  | Log | ${event} |
         | END |
         """
